# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: applications_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import applications_common_pb2 as applications__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61pplications_service.proto\x12 armonik.api.grpc.v1.applications\x1a\x19\x61pplications_common.proto2\x9c\x01\n\x0c\x41pplications\x12\x8b\x01\n\x10ListApplications\x12\x39.armonik.api.grpc.v1.applications.ListApplicationsRequest\x1a:.armonik.api.grpc.v1.applications.ListApplicationsResponse\"\x00\x42#\xaa\x02 ArmoniK.Api.gRPC.V1.Applicationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'applications_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002 ArmoniK.Api.gRPC.V1.Applications'
  _globals['_APPLICATIONS']._serialized_start=92
  _globals['_APPLICATIONS']._serialized_end=248
# @@protoc_insertion_point(module_scope)
