# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: partitions_fields.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17partitions_fields.proto\x12\x1e\x61rmonik.api.grpc.v1.partitions\"Y\n\x11PartitionRawField\x12\x44\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x35.armonik.api.grpc.v1.partitions.PartitionRawEnumField\"k\n\x0ePartitionField\x12P\n\x13partition_raw_field\x18\x01 \x01(\x0b\x32\x31.armonik.api.grpc.v1.partitions.PartitionRawFieldH\x00\x42\x07\n\x05\x66ield*\xc1\x02\n\x15PartitionRawEnumField\x12(\n$PARTITION_RAW_ENUM_FIELD_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPARTITION_RAW_ENUM_FIELD_ID\x10\x01\x12\x31\n-PARTITION_RAW_ENUM_FIELD_PARENT_PARTITION_IDS\x10\x02\x12)\n%PARTITION_RAW_ENUM_FIELD_POD_RESERVED\x10\x03\x12$\n PARTITION_RAW_ENUM_FIELD_POD_MAX\x10\x04\x12\x32\n.PARTITION_RAW_ENUM_FIELD_PREEMPTION_PERCENTAGE\x10\x05\x12%\n!PARTITION_RAW_ENUM_FIELD_PRIORITY\x10\x06\x42!\xaa\x02\x1e\x41rmoniK.Api.gRPC.V1.Partitionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'partitions_fields_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\036ArmoniK.Api.gRPC.V1.Partitions'
  _globals['_PARTITIONRAWENUMFIELD']._serialized_start=260
  _globals['_PARTITIONRAWENUMFIELD']._serialized_end=581
  _globals['_PARTITIONRAWFIELD']._serialized_start=59
  _globals['_PARTITIONRAWFIELD']._serialized_end=148
  _globals['_PARTITIONFIELD']._serialized_start=150
  _globals['_PARTITIONFIELD']._serialized_end=257
# @@protoc_insertion_point(module_scope)
