# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: events_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import result_status_pb2 as result__status__pb2
from . import task_status_pb2 as task__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x65vents_common.proto\x12\x1a\x61rmonik.api.grpc.v1.events\x1a\x13result_status.proto\x1a\x11task_status.proto\".\n\x18\x45ventSubscriptionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\xa5\t\n\x19\x45ventSubscriptionResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x64\n\x12task_status_update\x18\x02 \x01(\x0b\x32\x46.armonik.api.grpc.v1.events.EventSubscriptionResponse.TaskStatusUpdateH\x00\x12h\n\x14result_status_update\x18\x03 \x01(\x0b\x32H.armonik.api.grpc.v1.events.EventSubscriptionResponse.ResultStatusUpdateH\x00\x12\x66\n\x13result_owner_update\x18\x04 \x01(\x0b\x32G.armonik.api.grpc.v1.events.EventSubscriptionResponse.ResultOwnerUpdateH\x00\x12Q\n\x08new_task\x18\x05 \x01(\x0b\x32=.armonik.api.grpc.v1.events.EventSubscriptionResponse.NewTaskH\x00\x12U\n\nnew_result\x18\x06 \x01(\x0b\x32?.armonik.api.grpc.v1.events.EventSubscriptionResponse.NewResultH\x00\x1a`\n\x10TaskStatusUpdate\x12\x0f\n\x07task_id\x18\n \x01(\t\x12;\n\x06status\x18\x0b \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x1ah\n\x12ResultStatusUpdate\x12\x11\n\tresult_id\x18\x14 \x01(\t\x12?\n\x06status\x18\x15 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x1a[\n\x11ResultOwnerUpdate\x12\x11\n\tresult_id\x18\x1e \x01(\t\x12\x19\n\x11previous_owner_id\x18\x1f \x01(\t\x12\x18\n\x10\x63urrent_owner_id\x18  \x01(\t\x1a\xeb\x01\n\x07NewTask\x12\x0f\n\x07task_id\x18( \x01(\t\x12\x12\n\npayload_id\x18) \x01(\t\x12\x16\n\x0eorigin_task_id\x18* \x01(\t\x12;\n\x06status\x18+ \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x1c\n\x14\x65xpected_output_keys\x18, \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18- \x03(\t\x12\x14\n\x0cretry_of_ids\x18. \x03(\t\x12\x17\n\x0fparent_task_ids\x18/ \x03(\t\x1aq\n\tNewResult\x12\x11\n\tresult_id\x18\x32 \x01(\t\x12\x10\n\x08owner_id\x18\x33 \x01(\t\x12?\n\x06status\x18\x34 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatusB\x08\n\x06updateB\x1d\xaa\x02\x1a\x41rmoniK.Api.gRPC.V1.Eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'events_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\032ArmoniK.Api.gRPC.V1.Events'
  _globals['_EVENTSUBSCRIPTIONREQUEST']._serialized_start=91
  _globals['_EVENTSUBSCRIPTIONREQUEST']._serialized_end=137
  _globals['_EVENTSUBSCRIPTIONRESPONSE']._serialized_start=140
  _globals['_EVENTSUBSCRIPTIONRESPONSE']._serialized_end=1329
  _globals['_EVENTSUBSCRIPTIONRESPONSE_TASKSTATUSUPDATE']._serialized_start=671
  _globals['_EVENTSUBSCRIPTIONRESPONSE_TASKSTATUSUPDATE']._serialized_end=767
  _globals['_EVENTSUBSCRIPTIONRESPONSE_RESULTSTATUSUPDATE']._serialized_start=769
  _globals['_EVENTSUBSCRIPTIONRESPONSE_RESULTSTATUSUPDATE']._serialized_end=873
  _globals['_EVENTSUBSCRIPTIONRESPONSE_RESULTOWNERUPDATE']._serialized_start=875
  _globals['_EVENTSUBSCRIPTIONRESPONSE_RESULTOWNERUPDATE']._serialized_end=966
  _globals['_EVENTSUBSCRIPTIONRESPONSE_NEWTASK']._serialized_start=969
  _globals['_EVENTSUBSCRIPTIONRESPONSE_NEWTASK']._serialized_end=1204
  _globals['_EVENTSUBSCRIPTIONRESPONSE_NEWRESULT']._serialized_start=1206
  _globals['_EVENTSUBSCRIPTIONRESPONSE_NEWRESULT']._serialized_end=1319
# @@protoc_insertion_point(module_scope)
