# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: worker_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import objects_pb2 as objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13worker_common.proto\x12\x1a\x61rmonik.api.grpc.v1.worker\x1a\robjects.proto\"\xde\x05\n\x0eProcessRequest\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12J\n\x07\x63ompute\x18\x02 \x01(\x0b\x32\x39.armonik.api.grpc.v1.worker.ProcessRequest.ComputeRequest\x1a\xe2\x04\n\x0e\x43omputeRequest\x12]\n\x0cinit_request\x18\x01 \x01(\x0b\x32\x45.armonik.api.grpc.v1.worker.ProcessRequest.ComputeRequest.InitRequestH\x00\x12\x31\n\x07payload\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12W\n\tinit_data\x18\x03 \x01(\x0b\x32\x42.armonik.api.grpc.v1.worker.ProcessRequest.ComputeRequest.InitDataH\x00\x12.\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x1a\xf4\x01\n\x0bInitRequest\x12\x39\n\rconfiguration\x18\x01 \x01(\x0b\x32\".armonik.api.grpc.v1.Configuration\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x0f\n\x07task_id\x18\x03 \x01(\t\x12\x36\n\x0ctask_options\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12\x1c\n\x14\x65xpected_output_keys\x18\x05 \x03(\t\x12/\n\x07payload\x18\x06 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunk\x1a\x36\n\x08InitData\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x13\n\tlast_data\x18\x02 \x01(\x08H\x00\x42\x06\n\x04typeB\x06\n\x04type\"X\n\x0cProcessReply\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12+\n\x06output\x18\x02 \x01(\x0b\x32\x1b.armonik.api.grpc.v1.Output\"\x9a\x01\n\x10HealthCheckReply\x12J\n\x06status\x18\x01 \x01(\x0e\x32:.armonik.api.grpc.v1.worker.HealthCheckReply.ServingStatus\":\n\rServingStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x12\x0f\n\x0bNOT_SERVING\x10\x02\x42\x1d\xaa\x02\x1a\x41rmoniK.Api.gRPC.V1.Workerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'worker_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\032ArmoniK.Api.gRPC.V1.Worker'
  _globals['_PROCESSREQUEST']._serialized_start=67
  _globals['_PROCESSREQUEST']._serialized_end=801
  _globals['_PROCESSREQUEST_COMPUTEREQUEST']._serialized_start=191
  _globals['_PROCESSREQUEST_COMPUTEREQUEST']._serialized_end=801
  _globals['_PROCESSREQUEST_COMPUTEREQUEST_INITREQUEST']._serialized_start=493
  _globals['_PROCESSREQUEST_COMPUTEREQUEST_INITREQUEST']._serialized_end=737
  _globals['_PROCESSREQUEST_COMPUTEREQUEST_INITDATA']._serialized_start=739
  _globals['_PROCESSREQUEST_COMPUTEREQUEST_INITDATA']._serialized_end=793
  _globals['_PROCESSREPLY']._serialized_start=803
  _globals['_PROCESSREPLY']._serialized_end=891
  _globals['_HEALTHCHECKREPLY']._serialized_start=894
  _globals['_HEALTHCHECKREPLY']._serialized_end=1048
  _globals['_HEALTHCHECKREPLY_SERVINGSTATUS']._serialized_start=990
  _globals['_HEALTHCHECKREPLY_SERVINGSTATUS']._serialized_end=1048
# @@protoc_insertion_point(module_scope)
